Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Forum ¶
type Forum struct {
Name string
Posts int
Description string
Threads int
URL string
LastPost LastPost
}
Forum represents a forum
func GetForumList ¶
GetForumList returns a list of available forums
func (*Forum) GetThreadList ¶
GetThreadList returns a list of threads for the given forum/page
type LastPost ¶
type LastPost struct {
Author string
URL string
CreatedAt time.Time
Achievement PostAchievement
}
LastPost represents a forum last post
type Post ¶
type Post struct {
Staff bool
ValuedPoster bool
Content string
ContentText string
Author string
Badges []*client.Badge
Avatar string
Achievement PostAchievement
CreatedAt time.Time
}
Post thread post content
type PostAchievement ¶
PostAchievement post league achievements
type PostList ¶
type PostList struct {
List []*Post
Title string
ForumName string
ForumURL string
Items []*client.Item
Pagination *util.Pagination
}
PostList thread post list
type Thread ¶
type Thread struct {
ID int64
Staff bool
Support bool
Sticky bool
Locked bool
Title string
Replies int
Views int
URL string
Author string
CreatedAt time.Time
Pagination *util.Pagination
}
Thread forum thread
func (*Thread) GetPostList ¶
GetPostList returns the list of posts for the given thread
type ThreadList ¶
type ThreadList struct {
ForumName string
Pagination *util.Pagination
List []*Thread
}
ThreadList forum thread list
Click to show internal directories.
Click to hide internal directories.